@@ -8,6 +8,7 @@ OC.L10N.register(
     "Cheers!" : "Geluk!",
     "Calendar" : "Kalender",
     "Confirm" : "Bevestig",
+    "Location:" : "Ligging:",
     "A Calendar app for Nextcloud" : "'n Kalendertoep vir Nextcloud",
     "Today" : "Vandag",
     "Day" : "Dag",
@@ -30,12 +31,15 @@ OC.L10N.register(
     "Share with users or groups" : "Deel met gebruikers of groepe",
     "No users or groups" : "Geen gebruikers of groepe",
     "Save" : "Stoor",
+    "View" : "Bekyk",
     "Filename" : "Lêernaam",
     "Cancel" : "Kanselleer",
     "Automatic" : "Outomaties",
+    "Timezone" : "Tydsone",
     "List view" : "Lysaansig",
     "Actions" : "Aksies",
     "Show week numbers" : "Toon weeknommers",
+    "Keyboard shortcuts" : "Sneltoetse",
     "Update" : "Werk by",
     "Location" : "Ligging",
     "Description" : "Beskrywing",
@@ -76,6 +80,7 @@ OC.L10N.register(
     "Personal" : "Persoonlik",
     "All day" : "Heeldag",
     "Close" : "Sluit",
+    "Submit" : "Dien in",
     "Anniversary" : "Herdenking",
     "Week {number} of {year}" : "Week {number} van {year}",
     "Daily" : "Daagliks",
