@@ -182,7 +182,6 @@ OC.L10N.register(
     "Save edited event" : "Tahrirlangan tadbirni saqlang",
     "Delete edited event" : "Tahrirlangan tadbirni oʻchirish",
     "Duplicate event" : "Tadbirni nusxalash",
-    "Shortcut overview" : "Qisqa komandalar haqida umumiy ma'lumot",
     "or" : "yoki",
     "Calendar settings" : "Taqvim sozlamalari",
     "At event start" : "Tadbir boshlanishida",
@@ -190,19 +189,16 @@ OC.L10N.register(
     "Failed to save default calendar" : "Standart taqvim saqlanmadi",
     "CalDAV link copied to clipboard." : "CalDAV havolasi vaqtinchalik xotiraga nusxalandi.",
     "CalDAV link could not be copied to clipboard." : "CalDAV havolasini vaqtinchalik xotiraga nusxalab bo‘lmadi.",
-    "Enable birthday calendar" : "Tug'ilgan kun taqvimini yoqing",
-    "Show tasks in calendar" : "Taqvimdagi vazifalarni ko'rsatish",
-    "Enable simplified editor" : "Soddalashtirilgan muharrirni yoqing",
-    "Limit the number of events displayed in the monthly view" : "Oylik ko'rinishda ko'rsatiladigan voqealar sonini cheklang",
-    "Show weekends" : "Dam olish kunlarini ko'rsatish",
-    "Show week numbers" : "Hafta tartib raqamlarini ko'rsatish",
-    "Time increments" : "Vaqt o'sishi",
-    "Default calendar for incoming invitations" : "Kiruvchi taklifnomalar uchun standart taqvim",
-    "Default reminder" : "Standart eslatma",
+    "General" : "Umumiy",
+    "Personal availability settings" : "Shaxsiy ochiqlik sozlamalari",
     "Copy primary CalDAV address" : "Asosiy CalDAV manzilidan nusxa oling",
     "Copy iOS/macOS CalDAV address" : "iOS/macOS CalDAV manzilidan nusxa oling",
-    "Personal availability settings" : "Shaxsiy ochiqlik sozlamalari",
-    "Show keyboard shortcuts" : "Klaviatura yorliqlarini ko'rsatish",
+    "Enable birthday calendar" : "Tug'ilgan kun taqvimini yoqing",
+    "Show tasks in calendar" : "Taqvimdagi vazifalarni ko'rsatish",
+    "Show weekends" : "Dam olish kunlarini ko'rsatish",
+    "Show week numbers" : "Hafta tartib raqamlarini ko'rsatish",
+    "Default calendar for incoming invitations" : "Kiruvchi taklifnomalar uchun standart taqvim",
+    "Default reminder" : "Standart eslatma",
     "Appointment schedule successfully created" : "Uchrashuv jadvali yaratildi",
     "Appointment schedule successfully updated" : "Uchrashuv jadvali muvaffaqiyatli yangilandi",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minut"],
@@ -476,6 +472,7 @@ OC.L10N.register(
     "Close" : "Yopish",
     "Modifications will not get propagated to the organizer and other attendees" : "O'zgartirishlar tashkilotchiga va boshqa ishtirokchilarga targ'ib qilinmaydi",
     "Title" : "Sarlavha",
+    "30 min" : "30 daqiqa",
     "Subscribe to {name}" : " {name}ga obuna bo'ling",
     "Export {name}" : " {name}eksporti",
     "Show availability" : "Mavjudligini ko'rsatish",
@@ -575,6 +572,11 @@ OC.L10N.register(
     "This is an event reminder." : "Bu tadbir eslatmasi.",
     "Error while parsing a PROPFIND error" : "PROPFIND xatosini tahlil qilishda xatolik yuz berdi",
     "Appointment not found" : "Uchrashuv topilmadi",
-    "User not found" : "Foydalanuvchi topilmadi"
+    "User not found" : "Foydalanuvchi topilmadi",
+    "Shortcut overview" : "Qisqa komandalar haqida umumiy ma'lumot",
+    "Enable simplified editor" : "Soddalashtirilgan muharrirni yoqing",
+    "Limit the number of events displayed in the monthly view" : "Oylik ko'rinishda ko'rsatiladigan voqealar sonini cheklang",
+    "Time increments" : "Vaqt o'sishi",
+    "Show keyboard shortcuts" : "Klaviatura yorliqlarini ko'rsatish"
 },
 "nplurals=1; plural=0;");
