@@ -1,6 +1,7 @@
 OC.L10N.register(
     "calendar",
     {
+    "Provided email-address is too long" : "Mail được nhập quá dài",
     "User-Session unexpectedly expired" : "Tiến trình của người dùng đã hết hạn một cách không được mong đợi trước",
     "Provided email-address is not valid" : "Thư điện tử được cung cấp không khả dụng",
     "%s has published the calendar »%s«" : "%s vừa đăng tải thông tin vào lịch »%s«",
@@ -13,26 +14,40 @@ OC.L10N.register(
     "Upcoming events" : "Các sự kiện sắp diễn ra",
     "No more events today" : "Không có thêm sự kiện nào hôm nay",
     "No upcoming events" : "Không có sự kiện sắp diễn ra ",
+    "More events" : "Sự kiện khác",
+    "%1$s with %2$s" : "%1$s với %2$s",
     "Calendar" : "Lịch",
+    "New booking {booking}" : "Book lịch mới{booking}",
+    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) đã book lịch hẹn với \"{config_display_name}\" vào {date_time}.",
     "Appointments" : "Các lịch hẹn ",
     "Schedule appointment \"%s\"" : "Lên lịch lịch hẹn \"%s\"",
     "Schedule an appointment" : "Lên lịch một lịch hẹn",
+    "%1$s - %2$s" : "%1$s-%2$s",
     "Prepare for %s" : "Chuản bị cho %s",
     "Follow up for %s" : "Diễn tiến cho %s",
     "Dear %s, please confirm your booking" : "%s thân ái, vui lòng xác nhận lịch đặt hẹn của bạn",
     "Confirm" : "Xác nhận",
     "Description:" : "Mô tả:",
     "This confirmation link expires in %s hours." : "Liên kết xác nhận sẽ hết hạn trong %s giờ.",
+    "Appointment for:" : "Lịch hẹn cho: ",
     "Date:" : "Ngày:",
+    "You will receive a link with the confirmation email" : "Bạn sẽ nhận được liên kết cùng với email xác nhận",
     "Where:" : "Địa điểm:",
+    "Comment:" : "Bình luận",
+    "You have a new appointment booking \"%s\" from %s" : "Bạn có lịch hẹn mới được book bởi \"%s\" vào lúc %s",
+    "Dear %s, %s (%s) booked an appointment with you." : "Gửi %s,%s(%s) đã book lịch hẹn với bạn.",
+    "Location:" : "Đến từ :",
     "A Calendar app for Nextcloud" : "Một ứng dụng Lịch nhắc nhở cho Hệ thống",
     "Previous day" : "Ngày trước",
     "Previous week" : "Tuần trước",
+    "Previous year" : "Năm trước",
     "Previous month" : "Tháng trước",
     "Next day" : "Ngày hôm sau",
     "Next week" : "Tuần sau",
     "Next year" : "Năm tiếp theo",
     "Next month" : "Tháng sau",
+    "Create new event" : "Tạo sự kiện mới",
+    "Event" : "Sự kiện",
     "Today" : "Hôm nay",
     "Day" : "Ngày",
     "Week" : "Tuần",
@@ -45,6 +60,7 @@ OC.L10N.register(
     "Copy link" : "Sao chép liên kết",
     "Edit" : "Chỉnh sửa",
     "Delete" : "Xóa",
+    "Appointment schedules" : "Lên lịch hẹn",
     "Create new" : "Tạo mới",
     "An error occurred, unable to change visibility of the calendar." : "Một lỗi đã xảy ra, không thể thay đổi tính hiển thị của lịch.",
     "Untitled calendar" : "Lịch không tiêu đề",
@@ -104,6 +120,7 @@ OC.L10N.register(
     "No users or groups" : "Không có người dùng hay nhóm",
     "Unshare from me" : "Gỡ chia sẻ khỏi tôi",
     "Save" : "Lưu",
+    "View" : "Xem",
     "Import calendars" : "Nhập lịch",
     "Please select a calendar to import into …" : "Vui lòng chọn một lịch để nhập vào  …",
     "Filename" : "Tên tập tin",
@@ -117,6 +134,7 @@ OC.L10N.register(
     "Automatic" : "Tự động",
     "Automatic ({detected})" : " ({detected}) tự động",
     "New setting was not saved successfully." : "Thiết lập mới không được lưu thành công",
+    "Timezone" : "Múi giờ",
     "Navigation" : "Điều hướng",
     "Previous period" : "Kỳ trước",
     "Next period" : "Kỳ tiếp theo",
@@ -132,22 +150,21 @@ OC.L10N.register(
     "Close editor" : "Đóng trình biên tập",
     "Save edited event" : "Lưu lại sự kiện được chỉnh sửa",
     "Delete edited event" : "Xoá sự kiện được chỉnh sửa",
-    "Shortcut overview" : "Bản xem trước của lối tắt",
     "or" : "hoặc",
     "No reminder" : "Không có nhắc hẹn",
     "CalDAV link copied to clipboard." : "Liên kết CalDAV đã được sao chép vào bảng tạm",
     "CalDAV link could not be copied to clipboard." : "Liên kết CalDAV không thể được sao chép vào bảng tạm.",
-    "Enable birthday calendar" : "Bật lịch sinh nhật",
-    "Show tasks in calendar" : "Cho thấy nhiệm vụ trong lịch",
-    "Enable simplified editor" : "Bật chỉnh sửa đơn giản",
-    "Show weekends" : "Cho thấy ngày cuối tuần",
-    "Show week numbers" : "Hiển thị số tuần",
-    "Time increments" : "Mức tăng thời gian",
-    "Default reminder" : "Nhác hẹn mặc định",
+    "General" : "Cài đặt chung",
+    "Personal availability settings" : "Thiết lập lịch trống cá nhân",
     "Copy primary CalDAV address" : "Sao chép địa chỉ CalDAV chính",
     "Copy iOS/macOS CalDAV address" : "Sao chép địa chỉ CalDAV cho iOS/macOC",
-    "Personal availability settings" : "Thiết lập lịch trống cá nhân",
-    "Show keyboard shortcuts" : "Hiển thị các phím tắt",
+    "Enable birthday calendar" : "Bật lịch sinh nhật",
+    "Show tasks in calendar" : "Cho thấy nhiệm vụ trong lịch",
+    "Show weekends" : "Cho thấy ngày cuối tuần",
+    "Show week numbers" : "Hiển thị số tuần",
+    "Editing" : "Chỉnh sửa",
+    "Default reminder" : "Nhác hẹn mặc định",
+    "Keyboard shortcuts" : "Phím tắt",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} phút"],
     "0 minutes" : "0 phút",
     "_{duration} hour_::_{duration} hours_" : ["{duration} giờ"],
@@ -194,7 +211,6 @@ OC.L10N.register(
     "Select conversation" : "Chọn cuộc trò chuyện",
     "on" : "trên",
     "at" : "vào lúc",
-    "Reminder" : "Lịch nhắc hẹn",
     "before at" : "trước lúc",
     "Notification" : "Thông báo",
     "Email" : "Thư điện tử",
@@ -205,7 +221,6 @@ OC.L10N.register(
     "Edit time" : "Chỉnh sửa thời gian",
     "Save time" : "Lưu thời gian",
     "Remove reminder" : "Gỡ bỏ lịch nhắc hẹn",
-    "+ Add reminder" : "+ Thêm lịch nhắc hẹn",
     "Add reminder" : "Thêm vào nhắc hẹn",
     "seconds" : "giây",
     "minutes" : "phút",
@@ -225,14 +240,14 @@ OC.L10N.register(
     "Declined {organizerName}'s invitation" : "Đã từ chối lời mời của {organizerName}",
     "Checking availability" : "Đang kiểm tra lịch trống",
     "{organizer} (organizer)" : "{organizer} (người tổ chức)",
+    "Availability of attendees, resources and rooms" : "Tình trạng tham gia của người dự, nguồn lực và phòng ",
+    "Out of office" : "Không ở văn phòng",
+    "Done" : "Hoàn thành",
+    "Room name" : "Tên phòng",
     "Free" : "Rãnh",
     "Busy (tentative)" : "Bận (có khả năng thay đổi)",
     "Busy" : "Bận",
-    "Out of office" : "Không ở văn phòng",
     "Unknown" : "Không xác định",
-    "Availability of attendees, resources and rooms" : "Tình trạng tham gia của người dự, nguồn lực và phòng ",
-    "Done" : "Hoàn thành",
-    "Room name" : "Tên phòng",
     "Accept" : "Đồng ý",
     "Decline" : "Từ chối",
     "Tentative" : "Chưa chắc chắn",
@@ -254,7 +269,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Không thể điều chỉnh thiết lập cả-ngày cho các sự kiện là một phần của sự kiện-lặp lại.",
     "From" : "Từ",
     "To" : "Tới",
-    "All day" : "Cả ngày",
     "Repeat" : "Lặp lại",
     "_time_::_times_" : ["lần"],
     "never" : "không thay đổi",
@@ -277,7 +291,7 @@ OC.L10N.register(
     "Does not repeat" : "Không lặp lại",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Định nghĩa về định kỳ của sự kiện này không hoàn toàn được hỗ trợ bởi vWorkspace. Nếu bạn sửa các lựa chọn định kỳ này, một vài định kỳ có thể sẽ bị mất ",
     "No rooms or resources yet" : "Chưa có phòng hoặc nguồn lực",
-    "Suggestions" : "Các đề suất",
+    "Resources" : "Các nguồn lực",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} chỗ ngồi"],
     "Add resource" : "Thêm nguồn lực",
     "Has a projector" : "Có máy chiếu",
@@ -296,6 +310,9 @@ OC.L10N.register(
     "Update this occurrence" : "Cập nhập định kỳ này",
     "Public calendar does not exist" : "Lịch công khai không tồn tại",
     "Maybe the share was deleted or has expired?" : "Có lẽ chia sẽ đã bị xóa hoặc hết hạn ? ",
+    "Yes" : "Có",
+    "No" : "Không",
+    "Create" : "Tạo",
     "from {formattedDate}" : "từ {formattedDate}",
     "to {formattedDate}" : "đến {formattedDate}",
     "on {formattedDate}" : "vào {formattedDate}",
@@ -328,14 +345,17 @@ OC.L10N.register(
     "Personal" : "Cá nhân",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Chức năng tự động phát hiện múi giờ đã xác định múi giờ của bạn là UTC. \nRất có khả năng đây là kết quả lấy từ các tuỳ chỉnh bảo mật trong trình duyệt của bạn.\nVui lòng chuyển đổi thủ công múi của giờ của bạn trong phần thiết lập của Lịch",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Không tìm thấy múi giờ ({timezoneId}) được cấu hình của bạn. Thiết lập múi giờ sẽ được trở về lại UTC. Vui lòng thay đổi múi giờ của bạn trong phần cài đặt và hãy báo cáo sự cố này. ",
+    "Edit event" : "Sửa sự kiện",
     "Event does not exist" : "Sự kiện không tồn tại",
     "Delete this occurrence" : "Xóa định kỳ này",
     "Delete this and all future" : "Xóa địnhy kỳ này và tất cả tương lai của nó",
-    "Details" : "Chi tiết",
+    "All day" : "Cả ngày",
     "Invite" : "Mời",
-    "Resources" : "Các nguồn lực",
     "Untitled event" : "Sự kiện không tiêu đề",
     "Close" : "Đóng",
+    "Title" : "Tên",
+    "Participants" : "Người tham gia",
+    "Submit" : "Gửi",
     "Subscribe to {name}" : "Dõi theo {name}",
     "Export {name}" : "Xuất dữ liệu bảng {name}",
     "Anniversary" : "Ngày kỷ niệm",
@@ -421,6 +441,10 @@ OC.L10N.register(
     "An error occurred, unable to delete the calendar." : "Một lỗi đã xảy ra, không thể xóa lịch.",
     "Imported {filename}" : " {filename} đã được nhập",
     "Appointment not found" : "Không tìm thấy cuộc hẹn",
-    "User not found" : "Không tìm thấy người dùng"
+    "User not found" : "Không tìm thấy người dùng",
+    "Shortcut overview" : "Bản xem trước của lối tắt",
+    "Enable simplified editor" : "Bật chỉnh sửa đơn giản",
+    "Time increments" : "Mức tăng thời gian",
+    "Show keyboard shortcuts" : "Hiển thị các phím tắt"
 },
 "nplurals=1; plural=0;");
